@@ -422,7 +422,8 @@ from sqlalchemy import sql
         check.check_http_status_code(response=_res)
         meta = _res.json()
         version_file_ids = meta.get('context', {}).get('version_file_id', {})
-        version_file_ids = [elm[-1] for elm in sorted(version_file_ids.items(), reverse=True)]
+        version_file_ids = version_file_ids.values()
+        version_file_ids = sorted(version_file_ids, key=itemgetter('timestamp'), reverse=False)
         return version_file_ids
     
     
@@ -446,7 +447,7 @@ from sqlalchemy import sql
             
             ddf_current = listDatanode.get_list_datanode(
                 meta=meta, 
-                index=0, 
+                index=-1, 
                 headers=self._jwt_header,
                 base_uri=self._base_discovery_api,
                 storage_options=self._storage_options,
@@ -457,14 +458,14 @@ from sqlalchemy import sql
             
                 ddf_previous = listDatanode.get_list_datanode(
                     meta=meta, 
-                    index=1, 
+                    index=-2, 
                     headers=self._jwt_header,
                     base_uri=self._base_discovery_api,
                     storage_options=self._storage_options,
                     bucketName=bucket_name
                 )
             except Exception as e:
-                print(e)
+                if self._verbose: print(e)
                 ddf_previous = None
             
             return listDatanode.get_change_data(ddf_current, ddf_previous)
